==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QFutureInterfaceBase_shell.h <==
#ifndef QFUTUREINTERFACEBASE_SHELL_H
#define QFUTUREINTERFACEBASE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qconfig.h>
#if QT_CONFIG(future)
#include <QtCore/qfutureinterface.h>
#endif //QT_CONFIG(future)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qmutex.h>
#include <QtCore/qrunnable.h>
#if QT_CONFIG(thread)
#include <QtCore/qthreadpool.h>
#endif //QT_CONFIG(thread)
#include <QtJambi/CoreAPI>
#include <QtJambi/JObjectWrapper>
#include <QtJambiCore/hashes.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(future)

class QFutureInterfaceBase_shell : public QFutureInterfaceBase, public QtJambiShellInterface
{
public:
    QFutureInterfaceBase_shell(const QFutureInterfaceBase& other0);
    QFutureInterfaceBase_shell(QFutureInterfaceBase::State initialState0 = QFutureInterfaceBase::NoState);
    ~QFutureInterfaceBase_shell() override;

    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QFutureInterfaceBase_access : public QFutureInterfaceBase
{
    void __qt_cancel_QFutureInterfaceBase_CancelMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
    void __qt_cleanContinuation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_derefT(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isRunningOrPending(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_launchAsync(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_refT(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_reset(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_rethrowPossibleException(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_runContinuation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setContinuation_QFutureInterfaceBase_Continuation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject func0);
    void __qt_setLaunchAsync_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean value0);
    static inline const std::type_info& __registerEnumTypeInfo_CancelMode() {
        return RegistryAPI::registerEnumTypeInfo<QFutureInterfaceBase::CancelMode>("QFutureInterfaceBase::CancelMode", "io/qt/core/QFutureInterfaceBase$CancelMode");
    }
};

#endif // QT_CONFIG(future)
#endif // QFUTUREINTERFACEBASE_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QFutureInterfaceBase_shell.h <==
#ifndef QFUTUREINTERFACEBASE_SHELL_H
#define QFUTUREINTERFACEBASE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qconfig.h>
#if QT_CONFIG(future)
#include <QtCore/qfutureinterface.h>
#endif //QT_CONFIG(future)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qmutex.h>
#include <QtCore/qrunnable.h>
#if QT_CONFIG(thread)
#include <QtCore/qthreadpool.h>
#endif //QT_CONFIG(thread)
#include <QtJambi/CoreAPI>
#include <QtJambi/JObjectWrapper>
#include <QtJambiCore/hashes.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(future)

class QFutureInterfaceBase_shell : public QFutureInterfaceBase, public QtJambiShellInterface
{
public:
    QFutureInterfaceBase_shell(const QFutureInterfaceBase& other0);
    QFutureInterfaceBase_shell(QFutureInterfaceBase::State initialState0 = QFutureInterfaceBase::NoState);
    ~QFutureInterfaceBase_shell() override;

    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QFutureInterfaceBase_access : public QFutureInterfaceBase
{
    void __qt_cancel_QFutureInterfaceBase_CancelMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
    void __qt_cleanContinuation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_derefT_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isRunningOrPending_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_launchAsync_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_refT_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_reset(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_rethrowPossibleException(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_runContinuation_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setContinuation_QFutureInterfaceBase_Continuation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject func0);
    void __qt_setLaunchAsync_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean value0);
    static inline const std::type_info& __registerEnumTypeInfo_CancelMode() {
        return RegistryAPI::registerEnumTypeInfo<QFutureInterfaceBase::CancelMode>("QFutureInterfaceBase::CancelMode", "io/qt/core/QFutureInterfaceBase$CancelMode");
    }
};

#endif // QT_CONFIG(future)
#endif // QFUTUREINTERFACEBASE_SHELL_H
